# Generated by Django 4.1.6 on 2023-02-17 08:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('anorganization', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='membership',
            name='attributes',
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='organization',
            name='attributes',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
